# Contributing

Thank you for your interest in contributing to the project! We welcome all contributions. There are many different ways to contribute to Bloqade, and we are always looking for more help. We accept contributions in the form of bug reports, feature requests, documentation improvements, and code contributions. For more information about how to contribute, please read the following sections.


## Table of Contents

- [Reporting a Bug ](reporting-a-bug.md)
- [Reporting Documentation Issues](documentation-issues.md)
- [Feature Requests](feature-requests.md)
- [Developing Bloqade](../../contrib.md)
- [Design Philosophy and Architecture](design-philosophy-and-architecture.md)
- [Community Slack](community-slack.md)
- [Ask a Question](asking-a-question.md)
- [Providing Feedback](providing-feedback.md)
